==> haskell-microstache-1.0.1.1-52-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-HbWKwvE2DgOJkPg7gkeReE
key: microstache-1.0.1.1-HbWKwvE2DgOJkPg7gkeReE
license: BSD-3-Clause
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
abi: f1f61f3dd6d9cee40dbebd98196b1bbc
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
import-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-HbWKwvE2DgOJkPg7gkeReE
depends:
    aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47 base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 parsec-3.1.13.0
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47=f2b384712f64489a53b966926a554aaf
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.1.1-53-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-63ozCwzvTTL5kKcLwQiay1
key: microstache-1.0.1.1-63ozCwzvTTL5kKcLwQiay1
license: BSD-3-Clause
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
abi: de767c2d57cebc2c0df3280034755fda
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
import-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-63ozCwzvTTL5kKcLwQiay1
depends:
    aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 parsec-3.1.13.0
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX=703c560734a72c2a014a198df0039e3a
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
